==> tulip_2.0.2.orig.tar.gz: tulip-2.0.2/library/tulip-qt/include/tulip/MouseObject.h <==
//-*-c++-*-
#ifndef MOUSEOBJECT_H
#define MOUSEOBJECT_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <tulip/tulipconf.h>

#include <qcursor.h>

#include "MouseInterface.h"
///
class TLP_QT_SCOPE MouseRotXRotY:public MouseInterface
{
 public:
  MouseRotXRotY(){}
  ~MouseRotXRotY(){}
  int x,y;
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};
///
class TLP_QT_SCOPE MouseZoomRotZ:public MouseInterface
{
 public:
  MouseZoomRotZ(){}
  ~MouseZoomRotZ(){}
  int x,y;
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};
///
class TLP_QT_SCOPE MouseMove:public MouseInterface
{
 public:
  int x,y;
  MouseMove(){}
  ~MouseMove(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};
///
class TLP_QT_SCOPE MouseSelect:public MouseInterface
{
 public:
  MouseSelect(){}
  ~MouseSelect(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};
///
class TLP_QT_SCOPE MouseDel:public MouseInterface
{
public:
  MouseDel(){}
  ~MouseDel(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};

///
class TLP_QT_SCOPE MouseDelSelection:public MouseInterface
{
public:
  MouseDelSelection(){}
  ~MouseDelSelection(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
};

class TLP_QT_SCOPE MouseGraphNavigate: public MouseInterface
{
private:
  MouseInterface *currentMouse;
  MouseZoomRotZ mouseZoomRotZ;
  MouseRotXRotY mouseRotXRotY;
  MouseMove mouseMove;
  
public:
  MouseGraphNavigate();
  ~MouseGraphNavigate();
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *);
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *);
  void wheelEvent(GlGraphWidget *, QWheelEvent *);
};

class TLP_QT_SCOPE Mouse2D: public MouseInterface
{
private:
  MouseInterface *currentMouse;
  MouseSelect mouseSelect;
  MouseMove mouseMove;
  QCursor oldCursor;
public:
  Mouse2D();
  ~Mouse2D();
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *);
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *);
  void wheelEvent(GlGraphWidget *, QWheelEvent *);
};

#endif

==> tulip_2.0.6.orig.tar.gz: tulip-2.0.6/library/tulip-qt/include/tulip/MouseObject.h <==
//-*-c++-*-
#ifndef MOUSEOBJECT_H
#define MOUSEOBJECT_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <tulip/tulipconf.h>

#if (QT_REL == 3)
#include <qcursor.h>
#else
#include <QtGui/qcursor.h>
#endif

#include "MouseInterface.h"
/** \addtogroup Mouse_interactor */ 
/*@{*/
///
class TLP_QT_SCOPE MouseRotXRotY:public MouseInterface
{
 public:
  MouseRotXRotY(){}
  ~MouseRotXRotY(){}
  int x,y;
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
  MouseInterface * clone() { return new MouseRotXRotY();}
};
///
class TLP_QT_SCOPE MouseZoomRotZ:public MouseInterface
{
 public:
  MouseZoomRotZ(){}
  ~MouseZoomRotZ(){}
  int x,y;
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
  MouseInterface * clone() { return new MouseZoomRotZ();}
};
///
class TLP_QT_SCOPE MouseMove:public MouseInterface
{
 public:
  int x,y;
  MouseMove(){}
  ~MouseMove(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
  MouseInterface * clone() { return new MouseMove();}
};
///
class TLP_QT_SCOPE MouseSelect:public MouseInterface
{
 public:
  MouseSelect(){}
  ~MouseSelect(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
  MouseInterface * clone() { return new MouseSelect();}
};
///
class TLP_QT_SCOPE MouseDel:public MouseInterface
{
public:
  MouseDel(){}
  ~MouseDel(){}
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
  MouseInterface * clone() { return new MouseDel();}
};


class TLP_QT_SCOPE MouseGraphNavigate: public MouseInterface {
private:
  MouseInterface *currentMouse;
  MouseZoomRotZ mouseZoomRotZ;
  MouseRotXRotY mouseRotXRotY;
  MouseMove mouseMove;
  
public:
  MouseGraphNavigate();
  ~MouseGraphNavigate();
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *);
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *);
  void wheelEvent(GlGraphWidget *, QWheelEvent *);
  MouseInterface * clone() { return new MouseGraphNavigate();}
};

class TLP_QT_SCOPE Mouse2D: public MouseInterface
{
private:
  MouseInterface *currentMouse;
  MouseSelect mouseSelect;
  MouseMove mouseMove;
  QCursor oldCursor;
public:
  Mouse2D();
  ~Mouse2D();
  
  void mPressEvent(GlGraphWidget *,QMouseEvent *);
  void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
  void mMoveEvent(GlGraphWidget *,QMouseEvent *);
  void mPaint(GlGraphWidget *);
  void keyPressEvent (GlGraphWidget *, QKeyEvent *);
  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *);
  void wheelEvent(GlGraphWidget *, QWheelEvent *);
  MouseInterface * clone() { return new Mouse2D();}
};
/*@}*/
#endif
